#!/bin/sh
# Run this to generate all the initial makefiles, etc.

test -f configure.in || {
    echo -n "**Error**: This directory does not look like the"
    echo " top-level directory"
    exit 1
}

mv intl/CVS intlCVS 2>/dev/null
gettextize -f
mv intlCVS intl/CVS 2>/dev/null
aclocal
autoheader
automake -a
autoconf
